@@ -645,10 +645,13 @@ class Bitpin:
 
         return self._process_response(f_name, response, f_args)
 
-    def recent_trades(self):
+    def recent_trades(self, market_id: t.Optional[int]):
         """
         Get recent trades.
 
+        :param market_id: Market ID (optional)
+        :type market_id: int
+
         :return: Recent trades
         :rtype: dict
         """
@@ -665,12 +668,22 @@ class Bitpin:
             auth=True,
         )
 
-        return self._process_response(f_name, response, f_args)
+        processed_reponse = self._process_response(f_name, response, f_args)
 
-    def balances(self):
+        if market_id is not None:
+            filtered_results = [r for r in processed_reponse.get('results') if r['market']['id'] == market_id]
+
+            processed_reponse['results'] = filtered_results
+            
+        return processed_reponse
+
+    def balances(self, currency_id: t.Optional[int]):
         """
         Get balances.
 
+        :param currency_id: Currency ID (optional)
+        :type currency_id: int
+
         :return: Recent trades
         :rtype: dict
         """
@@ -687,7 +700,14 @@ class Bitpin:
             auth=True,
         )
 
-        return self._process_response(f_name, response, f_args)
+        processed_reponse = self._process_response(f_name, response, f_args)
+
+        if currency_id is not None:
+            filtered_results = [r for r in processed_reponse.get('results') if r['currency']['id'] == currency_id]
+
+            processed_reponse['results'] = filtered_results
+            
+        return processed_reponse
 
     def open_orders(self, market_id: t.Optional[int]):
         """
